==> PyNFe-1.0.22.tar.gz: PyNFe-1.0.22/pynfe/nfe/manual_600/conssitnfe.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagDecimal, TagCaracter, TagDataHoraUTC
from pynfe.xml_sped.base import NAMESPACE_NFE, XMLNFe, ABERTURA
from pynfe.xml_sped.assinatura import Signature
from pynfe.nfe.manual_500 import conssitnfe_310
from .nfe_400 import ESQUEMA_ATUAL
from .consrecinfe import ProtNFe
from .cancnfe import RetCancNFe
import os


DIRNAME = os.path.dirname(__file__)


class ConsSitNFe(conssitnfe_310.ConsSitNFe):
    def __init__(self):
        super(ConsSitNFe, self).__init__()
        self.versao = TagDecimal(nome='consSitNFe', codigo='EP01', propriedade='versao',
                                 namespace=NAMESPACE_NFE, valor='4.00', raiz='/')
        self.caminho_esquema = os.path.join(DIRNAME, 'schema', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'consSitNFe_v4.00.xsd'


class InfEvento(XMLNFe):
    def __init__(self):
        super(InfEvento, self).__init__()
        self.cOrgao = TagCaracter(nome='cOrgao', codigo='', tamanho=[2, 2, 2])


class Evento(XMLNFe):
    def __init__(self):
        super(Evento, self).__init__()
        self.infEvento = InfEvento
        self.signature = Signature()


class RetEvento(XMLNFe):
    def __init__(self):
        super(RetEvento, self).__init__()


class RetConsSitNFe(conssitnfe_310.RetConsSitNFe):
    def __init__(self):
        super(RetConsSitNFe, self).__init__()
        self.versao = TagDecimal(nome='retConsSitNFe', codigo='ER01', propriedade='versao',
                                 namespace=NAMESPACE_NFE, valor='4.00', raiz='/')
        self.dhRecbto = TagDataHoraUTC(nome='dhRecbto', codigo='ER07a', raiz='/')
        self.procEventoNFe = []
        self.caminho_esquema = os.path.join(DIRNAME, 'schema', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retConsSitNFe_v4.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.chNFe.xml
        if self.protNFe is not None:
            xml += self.protNFe.xml
        if self.retCancNFe is not None:
            xml += self.retCancNFe.raw_xml()
        for p in self.procEventoNFe:
            xml += p.xml
        xml += '</retConsSitNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.dhRecbto.xml = arquivo
            self.chNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/protNFe'):
                self.protNFe = ProtNFe()
                self.protNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/retCancNFe'):
                self.retCancNFe = RetCancNFe()
                self.retCancNFe.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> PyNFe-5.0.12.tar.gz: PyNFe-5.0.12/pynfe/nfe/manual_600/conssitnfe.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2017 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2017, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagDecimal, TagCaracter, TagDataHoraUTC
from pynfe.xml_sped.base import NAMESPACE_NFE, XMLNFe, ABERTURA
from pynfe.xml_sped.assinatura import Signature
from pynfe.nfe.manual_500 import conssitnfe_310
from .nfe_400 import ESQUEMA_ATUAL
from .consrecinfe import ProtNFe
from .cancnfe import RetCancNFe
import os


DIRNAME = os.path.dirname(__file__)


class ConsSitNFe(conssitnfe_310.ConsSitNFe):
    def __init__(self):
        super(ConsSitNFe, self).__init__()
        self.versao = TagDecimal(nome='consSitNFe', codigo='EP01', propriedade='versao',
                                 namespace=NAMESPACE_NFE, valor='4.00', raiz='/')
        self.caminho_esquema = os.path.join(DIRNAME, 'schema', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'consSitNFe_v4.00.xsd'


class InfEvento(XMLNFe):
    def __init__(self):
        super(InfEvento, self).__init__()
        self.cOrgao = TagCaracter(nome='cOrgao', codigo='', tamanho=[2, 2, 2])


class Evento(XMLNFe):
    def __init__(self):
        super(Evento, self).__init__()
        self.infEvento = InfEvento
        self.signature = Signature()


class RetEvento(XMLNFe):
    def __init__(self):
        super(RetEvento, self).__init__()


class RetConsSitNFe(conssitnfe_310.RetConsSitNFe):
    def __init__(self):
        super(RetConsSitNFe, self).__init__()
        self.versao = TagDecimal(nome='retConsSitNFe', codigo='ER01', propriedade='versao',
                                 namespace=NAMESPACE_NFE, valor='4.00', raiz='/')
        self.dhRecbto = TagDataHoraUTC(nome='dhRecbto', codigo='ER07a', raiz='/')
        self.procEventoNFe = []
        self.caminho_esquema = os.path.join(DIRNAME, 'schema', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retConsSitNFe_v4.00.xsd'

    @property
    def xml(self):
        xml = ABERTURA
        xml += self.versao.xml
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.chNFe.xml
        if self.protNFe is not None:
            xml += self.protNFe.xml
        if self.retCancNFe is not None:
            xml += self.retCancNFe.raw_xml
        for p in self.procEventoNFe:
            xml += p.xml
        xml += '</retConsSitNFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.dhRecbto.xml = arquivo
            self.chNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/protNFe'):
                self.protNFe = ProtNFe()
                self.protNFe.xml = arquivo
            if self._le_noh('//retConsSitNFe/retCancNFe'):
                self.retCancNFe = RetCancNFe()
                self.retCancNFe.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
